@@ -110,8 +110,9 @@ class Trainer:
                 split_datasets = full_dataset.train_test_split(test_size=self.arguments.validation_split)
                 self.raw_datasets["valid"] = split_datasets["test"]
                 self.raw_datasets["train"] = split_datasets["train"]
-            distributed = torch.distributed.is_initialized()
-            print("Distributed training:", distributed)
+            #distributed = torch.distributed.is_initialized()
+            #print("Distributed training:", distributed)
+            """
             if distributed:
                 n_proc = torch.distributed.get_world_size()
                 rank = torch.distributed.get_rank()
@@ -121,7 +122,7 @@ class Trainer:
                                                                                   index=rank)
                 if "valid" in self.raw_datasets.keys():
                     self.raw_datasets["valid"] = self.raw_datasets["valid"].shard(num_shards=n_proc,
-                                                                                  index=rank)
+                                                                                  index=rank)"""
             
     def GradCheckpoint(self):
         self.arguments.gradient_checkpointing = True
@@ -468,7 +469,7 @@ class Trainer:
             batched=True,
             num_proc=self.arguments.preprocessing_num_workers,
             remove_columns=column_names,
-            load_from_cache_file=not self.arguments.overwrite_cache,
+            load_from_cache_file=self.arguments.dataset_cache,
             desc="Running tokenizer on dataset",
         )
         if self.arguments.block_size is None:
@@ -498,7 +499,7 @@ class Trainer:
             group_texts,
             batched=True,
             num_proc=self.arguments.preprocessing_num_workers,
-            load_from_cache_file=not self.arguments.overwrite_cache,
+            load_from_cache_file=self.arguments.dataset_cache,
             desc=f"Grouping texts in chunks of {block_size}",
         )
         train_dataset = lm_datasets["train"]
@@ -560,7 +561,7 @@ class Trainer:
             batched=True,
             num_proc=self.arguments.preprocessing_num_workers,
             remove_columns=column_names,
-            load_from_cache_file=not self.arguments.overwrite_cache,
+            load_from_cache_file=self.arguments.dataset_cache,
             desc="Running tokenizer on train dataset",
         )
         if valid:
@@ -573,7 +574,7 @@ class Trainer:
                 batched=True,
                 num_proc=self.arguments.preprocessing_num_workers,
                 remove_columns=column_names,
-                load_from_cache_file=not self.arguments.overwrite_cache,
+                load_from_cache_file=self.arguments.dataset_cache,
                 desc="Running tokenizer on validation dataset",
             )
 
@@ -665,7 +666,7 @@ class Trainer:
             batched=True,
             num_proc=self.arguments.preprocessing_num_workers,
             remove_columns=column_names,
-            load_from_cache_file=not self.arguments.overwrite_cache,
+            load_from_cache_file=self.arguments.dataset_cache,
             desc="Running tokenizer on validation dataset",
         )
 
